@@ -24,16 +24,19 @@ class IsotopeTableDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit IsotopeTableDialog(QWidget* parent = nullptr);
+    explicit IsotopeTableDialog(QWidget *parent = nullptr);
 
 private:
     Ui::isotopeWidget ui;
 
+public Q_SLOTS:
+    void setMode(int mode);
+    void updateMode();
+
 private Q_SLOTS:
     void updateDockWidget(IsotopeItem *);
     void zoom(int);
     void slotZoomLevelChanged(double);
-
 };
 
 #endif // ISOTOPETABLEDIALOG_H
