@@ -19,8 +19,11 @@
 #include <QFont>
 #include <QPainter>
 #include <QStyleOption>
+#include <QGuiApplication>
+#include <QPalette>
 
 #include <KLocalizedString>
+#include <qbrush.h>
 
 #include "kalziumnumerationtype.h"
 
@@ -48,22 +51,21 @@ QPainterPath NumerationItem::shape() const
 
 void NumerationItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
 {
-    QPen pen;
-    QLinearGradient grad(QPointF(0, 0), QPointF(0, m_height));
-    grad.setColorAt(0, m_color);
-    grad.setColorAt(1, m_color.darker());
-    painter->setBrush(grad);
-    pen.setColor(m_color.darker(1000));
-    painter->setPen(pen);
+    QColor color = m_type == 0 ? QColor(Qt::transparent) : qGuiApp->palette().window().color();
+    painter->setBrush(color);
+    painter->setPen(Qt::NoPen);
 
     QRectF rect(0, 0, m_width, m_height);
-    painter->drawRoundedRect(rect, m_width / 10, m_width / 10);
+    painter->drawRoundedRect(rect, 3, 3);
+
+    QPen pen;
+    painter->setPen(qGuiApp->palette().text().color());
     painter->drawText(rect, Qt::AlignCenter, m_numeration);
 }
 
 void NumerationItem::setNumerationType(int type)
 {
-    type == 0 ? m_color = QColor(Qt::transparent) : m_color = QColor(Qt::white);
+    m_type = type;
 
     m_numeration = KalziumNumerationTypeFactory::instance()->build(type)->item(m_xPosition);
 
